@@ -26,6 +26,14 @@ class TestMemoryPubSub(unittest.TestCase):
         assert next(subscriber) == 'hello world!'
         assert next(subscriber) == 'hello universe!'
 
+    def test_not_subscribed_chan(self):
+        subscriber = self.pubsub.subscribe('a_chan', 'c_chan')
+        self.pubsub.publish('a_chan', 'hello world!')
+        self.pubsub.publish('b_chan', 'junk message')
+        self.pubsub.publish('c_chan', 'hello universe!')
+        assert next(subscriber) == 'hello world!'
+        assert next(subscriber) == 'hello universe!'
+
     def test_dispose_subscriber(self):
         subscriber = self.pubsub.subscribe('a_chan')
         assert self.pubsub.publish('a_chan', 'hello world!') == 1
