@@ -23,4 +23,12 @@ class TestMongoPubSub(unittest.TestCase):
         self.pubsub.publish('a_chan', 'hello world!')
         self.pubsub.publish('b_chan', 'hello universe!')
         assert next(subscriber) == 'hello world!'
+        assert next(subscriber) == 'hello universe!'
+
+    def test_not_subscribed_chan(self):
+        subscriber = self.pubsub.subscribe('a_chan', 'c_chan')
+        self.pubsub.publish('a_chan', 'hello world!')
+        self.pubsub.publish('b_chan', 'junk message')
+        self.pubsub.publish('c_chan', 'hello universe!')
+        assert next(subscriber) == 'hello world!'
         assert next(subscriber) == 'hello universe!'
\ No newline at end of file
